standardize_code_fences

Function standardize_code_fences 

pub fn standardize_code_fences(content: &str) -> String
Strip markdown-code-runner modifiers from all code fence language identifiers.

This is useful for making markdown files compatible with standard markdown processors like mkdocs and pandoc, which don’t understand the python markdown-code-runner syntax.

Examples

use markdown_code_runner::standardize::standardize_code_fences;

let content = "```python markdown-code-runner\nprint(\"hello\")\n```";
let result = standardize_code_fences(content);
assert_eq!(result, "```python\nprint(\"hello\")\n```");